Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(246)

Unified Diff: chrome/browser/budget_service/budget_database.cc

Issue 2487073004: Change the default budget expiration window to 4 days from 10 days. (Closed)
Patch Set: typo Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/budget_service/budget_database_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/budget_service/budget_database.cc
diff --git a/chrome/browser/budget_service/budget_database.cc b/chrome/browser/budget_service/budget_database.cc
index b4e7f88a5e0b0f2df3e53ebc428c6ba4fb7bc9bd..d59bc1d15a63556644720ba5c896d5764067cfdd 100644
--- a/chrome/browser/budget_service/budget_database.cc
+++ b/chrome/browser/budget_service/budget_database.cc
@@ -26,8 +26,8 @@ namespace {
const char kDatabaseUMAName[] = "BudgetManager";
// The default amount of time during which a budget will be valid.
-// This is 10 days = 240 hours.
-constexpr double kBudgetDurationInHours = 240;
+// This is 4 days = 96 hours.
+constexpr double kBudgetDurationInHours = 96;
} // namespace
« no previous file with comments | « no previous file | chrome/browser/budget_service/budget_database_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698